@@ -15,6 +15,7 @@ from .okx.client import Client as OKXClient
 from .bitmart.client import Client as BitmartClient
 from .gateio.client import Client as GateioClient
 from .hyperliquid.client import Client as HyperliquidClient
+from .async_support.bingx.client import Client as BingXClient
 
 
 # 在導入時自動應用（如果需要的話）
@@ -52,6 +53,11 @@ def hyperliquid(**kwargs):
     return HyperliquidClient(**kwargs)
 
 
+def bingx(**kwargs):
+    """Create a BingX client instance."""
+    return BingXClient(**kwargs)
+
+
 __all__ = [
     "bybit",
     "binance",
@@ -59,4 +65,5 @@ __all__ = [
     "bitmart",
     "gateio",
     "hyperliquid",
+    "bingx",
 ]
