@@ -1,7 +1,7 @@
 import asyncio
 import polars as pl
 from contextlib import asynccontextmanager
-from .fetch import bybit, okx, bitmart, gateio, binance, hyperliquid
+from .fetch import bybit, okx, bitmart, gateio, binance, hyperliquid, bingx
 
 VALID_EXCHANGES = [
     bybit,
@@ -10,6 +10,7 @@ VALID_EXCHANGES = [
     gateio,
     binance,
     hyperliquid,
+    bingx,
 ]
 
 
